@@ -12,12 +12,16 @@ model=$5
 if [ ! -d $userpath/tmp3  ];then
   mkdir $userpath/tmp3
 else
+  rm -r $userpath/tmp3
+  mkdir $userpath/tmp3
   echo "----------------------------tmp3 fold exist----------------------------"
 fi
 
 if [ ! -d $userpath/log ];then
   mkdir $userpath/log
 else
+  rm -r $userpath/log
+  mkdir $userpath/log
   echo "----------------------------log fold exist-----------------------------"
 fi
 
@@ -46,7 +50,7 @@ do
 done
 awk '{if(NF==6){print $1"\t"($2-2000)"\t"($3+2000)"\t"$4"\t"($5-2000)"\t"($6+2000)}}' $userpath/tmp3/target_comb.tmp > $userpath/tmp3/target_comb_final
 sort -k1,1 -k2,2n -k3,3n -k4,4 -k5,5n -k6,6n $userpath/tmp3/target_comb_final > $userpath/tmp3/target_comb_final.sort 
-targetFile=$userpath/tmp3/target_comb_final.sort
+targetFile=$userpath/tmp3/target_comb_final_sort.tmp
 
 for filename in $annoFile
 do
@@ -56,7 +60,7 @@ done >> $userpath/log/GRangeNeighbor_Log.txt
 wait
 echo "----------------------------Annotation done!-----------------------------"
 
-target_temp=$userpath/tmp3/target.tmp
+target_temp=$targetFile
 awk '{print $1"	"$2"	"$3}' $target_temp > $userpath/tmp3/anchor1.tmp
 awk '{print $4"	"$5"	"$6}' $target_temp > $userpath/tmp3/anchor2.tmp
 annotatePeaks.pl $userpath/tmp3/anchor1.tmp $genome  >  $userpath/tmp3/tmp_feature_tss_anchor1 && >> $userpath/log/Homer_log.txt
