@@ -64,7 +64,7 @@ do
     done
     awk '{if(NF==6){print $1"\t"($2-2000)"\t"($3+2000)"\t"$4"\t"($5-2000)"\t"($6+2000)}}' $userpath/tmp3/target_comb.tmp > $userpath/tmp3/target_comb_final
     sort -k1,1 -k2,2n -k3,3n -k4,4 -k5,5n -k6,6n $userpath/tmp3/target_comb_final > $userpath/tmp3/target_comb_final.sort 
-    targetFile=$userpath/tmp3/target_comb_final.sort
+    targetFile=$userpath/tmp3/target_comb_final_sort.tmp
     break
   fi
 done
@@ -83,7 +83,7 @@ wait
 echo "--------------Annotation done!----------------"
 
 # annotate the regions by homer
-target_temp=$userpath/tmp3/target_comb.tmp
+target_temp=$targetFile
 awk '{print $1"	"$2"	"$3}' $target_temp > $userpath/tmp3/anchor1.tmp
 awk '{print $4"	"$5"	"$6}' $target_temp > $userpath/tmp3/anchor2.tmp
 annotatePeaks.pl $userpath/tmp3/anchor1.tmp $genome  >  $userpath/tmp3/tmp_feature_tss_anchor1 &&
